============
pyannotables
============


.. image:: https://img.shields.io/pypi/v/pyannotables.svg
        :target: https://pypi.python.org/pypi/pyannotables


Python package for conversions between Ensembl IDs and gene names (annotables + pyranges + Ensembl GTF files)

* Free software: Apache Software License 2.0


Installation
------------

* `pip install pyannotables`


Features
--------

.. image:: notebook.png
   :scale: 30 %

   
Building data frames
---------------------

See `./build.ipynb
<https://nbviewer.ipython.org/github/gokceneraslan/pyannotables/blob/master/build.ipynb>`_.


Changelog
---------

* v0.5: Homology mapping table and function (`homology_convert`) are added. tables is a function now.
* v0.4: Entrez and UNIPROT IDs are added.
* v0.3: Ensembl version updated to 100. NCBI transcript IDs, gene lengths and gene exon lengths are added.


Credits
-------

* `annotables package in R` https://github.com/stephenturner/annotables
* `audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
